@@ -28,8 +28,8 @@ class Foresight(object):
         if do_print:
             for option in options:
                 print("{:30} - {:.2f} - {:.2f}".format(option[:30],
-                                                       option2p[option['original'],
-                                                       option2p[option['norm']))
+                                                       option2p[option]['original'],
+                                                       option2p[option]['norm']))
 
 
         return option2p
